@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # lesspipe.sh, a preprocessor for less
-lesspipe_version=2.08
+lesspipe_version=2.09
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 #( [[ -n 1 && -n 2 ]] ) > /dev/null 2>&1 || exec zsh -y --ksh-arrays -- "$0" ${1+"$@"}
 
@@ -9,10 +9,11 @@ has_cmd () {
 }
 
 fileext () {
-	case "$1" in
-		.*.*) extension=${1##*.};;
+	fn=${1##*/}
+	case "$fn" in
+		.*.*) extension=${fn##*.};;
 		.*) extension=;;
-		*.*) extension=${1##*.};;
+		*.*) extension=${fn##*.};;
 	esac
 	echo "$extension"
 }
@@ -74,6 +75,10 @@ filetype () {
 			[[ $ftype == json ]] && ftype=ipynb ;;
 		mp3)
 			[[ $ftype == mpeg ]] && ftype=mp3 ;;
+		jsx)
+			[[ $fcat == text ]] && ftype=$fext ;;
+		tsx)
+			[[ $fcat == text ]] && ftype=typescript-jsx ;;
 	esac
 	### get file type from 'file' command for an unspecific result
 	if [[ "$fcat" == message && $ftype == plain ]]; then
@@ -401,12 +406,12 @@ analyze_args () {
 	COLOR="--color=auto"
 	has_cmd tput && colors=$(tput colors) || colors=0
 	if [[ $colors -ge 8 ]]; then
+		[[ $LESS =~ -[A-Za-z~]*[rR] || $i = --raw-control-chars || $i = --RAW-CONTROL-CHARS ]] && COLOR="--color=always"
 		# shellcheck disable=SC2206
-		r_string=($LESS $lessarg)
+		r_string=($lessarg)
 		for i in "${r_string[@]}"
 		do
-			[[ $i = -*[rR] ]] && COLOR="--color=always"
-			[[ $i = --raw-control-chars ]] && COLOR="--color=always"
+			[[ $i =~ [\s]-[A-Za-z~]*[rR] || $i = --raw-control-chars || $i = --RAW-CONTROL-CHARS ]] && COLOR="--color=always"
 		done
 	fi
 	# last argument starting with colon or equal sign is used for piping into less
@@ -418,7 +423,7 @@ has_colorizer () {
 	[[ $2 == plain || -z $2 ]] && return
 	prog=${LESSCOLORIZER%% *}
 
-	for i in bat batcat pygmentize source-highlight code2color vimcolor ; do
+	for i in bat batcat pygmentize source-highlight vimcolor code2color ; do
 		[[ -z $prog || $prog == "$i" ]] && has_cmd "$i" && prog=$i
 	done
 	[[ "$2" =~ ^[0-9]*$ || -z "$2" ]] || lang=$2
@@ -426,7 +431,7 @@ has_colorizer () {
 	[[ -n $3 ]] && lang=$3 || lang=$2
 	case $prog in
 		bat|batcat)
-			[[ -n $lang ]] && $prog --list-languages|grep -i "$lang" > /dev/null && opt=(-l "$lang")
+			[[ -n $lang ]] && $prog --list-languages|sed 's/.*:/,/;s/$/,/'|grep -i ",$lang," > /dev/null && opt=(-l "$lang")
 			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--style=* ]] && style="${LESSCOLORIZER/* --style=/}"
 			[[ -z $style ]] && style=$BAT_STYLE
 			[[ -z $style ]] && style=plain
@@ -541,7 +546,9 @@ isfinal () {
 				[[ "$fext" == ms ]] && macro=s
 				cmd=(groff -s -p -t -e -Tutf8 -m "$macro" "$1")
 			elif has_cmd mandoc; then
-				cmd=(mandoc "$1")
+				cmd=(mandoc -l "$1")
+			elif has_cmd man; then
+				cmd=(man -l "$1")
 			fi ;;
 		rtf)
 			{ has_cmd unrtf && cmd=(istemp "unrtf --text" "$1"); } ||
@@ -576,11 +583,13 @@ isfinal () {
 			has_cmd ccze && [[ $COLOR = *always ]] && ccze -A < "$1"
 			return ;;
 		csv)
-			{ has_cmd csvlook && cmd=(csvlook "$1"); } ||
+			{ has_cmd column && cmd=(column -o "|" -s "	,;" -t "$1"); } ||
 			{ has_cmd pandoc && cmd=(pandoc -f csv -t plain "$1"); } ;;
 		json)
 			[[ $COLOR = *always ]] && opt=(-C .) || opt=(.)
 			has_cmd jq && cmd=(jq "${opt[@]}" "$1") ;;
+		zlib)
+			has_cmd zlib-flate && zlib-flate -uncompress < "$1" && return ;;
 	esac
 	fi
 	# not a specific file format
@@ -681,7 +690,7 @@ ispdf () {
 isrpm () {
 	if [[ -z "$2" ]]; then
 		if has_cmd rpm; then
-			istemp "rpm -qivp" "$1"
+			istemp "rpm -qivp --changelog --nomanifest --" "$1"
 			separatorline
 			[[ $1 == - ]] && set "$t" "$1"
 		fi
@@ -784,7 +793,7 @@ set +o noclobber
 setopt sh_word_split 2>/dev/null
 PATH=$PATH:${0%%/lesspipe.sh}
 # the current locale in lowercase (or generic utf-8)
-locale=$(locale|grep LC_CTYPE|sed 's/.*"\(.*\)"/\1/') || locale=en_US.UTF-8
+locale=$(locale|grep LC_CTYPE|tr -d '"') || locale=utf-8
 lclocale=$(echo "${locale##*.}"|tr '[:upper:]' '[:lower:]')
 
 sep=:					# file name separator
